@@ -249,6 +249,12 @@ class Message(object):
 
     headers = property(_get_headers)
 
+    def __eq__(self, other):
+        if not isinstance(other, self.__class__):
+            return False
+
+        return self.body == other.body
+
 
 class Request(Message):
     """
@@ -257,8 +263,8 @@ class Request(Message):
     @ivar target: The C{string} target of the request.
     """
 
-    def __init__(self, target, body=[], envelope=None):
-        Message.__init__(self, envelope, body)
+    def __init__(self, target, body=None, envelope=None):
+        Message.__init__(self, envelope, body or [])
 
         self.target = target
 
@@ -270,6 +276,12 @@ class Request(Message):
             type(self).__name__
         )
 
+    def __eq__(self, other):
+        if not super(Request, self).__eq__(other):
+            return False
+
+        return self.target == other.target
+
 
 class Response(Message):
     """
@@ -290,6 +302,12 @@ class Response(Message):
             type(self).__name__
         )
 
+    def __eq__(self, other):
+        if not super(Response, self).__eq__(other):
+            return False
+
+        return self.status == other.status
+
 
 class BaseFault(object):
     """
@@ -584,7 +602,8 @@ def get_fault(data):
     return get_fault_class(level, **e)(**e)
 
 
-def decode(stream, strict=False, logger=None, timezone_offset=None):
+def decode(stream, strict=False, logger=None, timezone_offset=None,
+           **kwargs):
     """
     Decodes the incoming stream as a remoting message.
 
@@ -623,7 +642,8 @@ def decode(stream, strict=False, logger=None, timezone_offset=None):
         pyamf.AMF0,
         stream,
         strict=strict,
-        timezone_offset=timezone_offset
+        timezone_offset=timezone_offset,
+        **kwargs
     )
     context = decoder.context
 
@@ -651,7 +671,7 @@ def decode(stream, strict=False, logger=None, timezone_offset=None):
     return msg
 
 
-def encode(msg, strict=False, logger=None, timezone_offset=None):
+def encode(msg, strict=False, logger=None, timezone_offset=None, **kwargs):
     """
     Encodes and returns the L{msg<Envelope>} as an AMF stream.
 
@@ -677,6 +697,7 @@ def encode(msg, strict=False, logger=None, timezone_offset=None):
         stream,
         strict=strict,
         timezone_offset=timezone_offset,
+        **kwargs
     )
 
     if msg.amfVersion == pyamf.AMF3:
